==> mnemosyne_0.9.8.1.orig.tar.gz: mnemosyne-0.9.8.1/mnemosyne/pyqt_ui/import_dlg.py <==
##############################################################################
#
# Widget to import items <Peter.Bienstman@UGent.be>
#
##############################################################################

from qt import *

from mnemosyne.core import *
from import_frm import *



##############################################################################
#
# ImportDlg
#
##############################################################################

class ImportDlg(ImportFrm):

    ##########################################################################
    #
    # __init__
    #
    ##########################################################################

    def __init__(self,parent = None,name = None,modal = 0,fl = 0):
        
        ImportFrm.__init__(self,parent,name,modal,fl)

        for fformat in get_importable_file_formats():
            self.fileformats.insertItem(fformat.name)
        self.fileformats.setCurrentText("Text with tab separated Q/A")

        self.categories.insertItem("<default>")
        for cat in get_categories():
            if cat.name != "<default>":
                self.categories.insertItem(cat.name)
        
        self.connect(self.browse_button, SIGNAL("clicked()"), self.browse)
        self.connect(self.ok_button, SIGNAL("clicked()"), self.apply)

    ##########################################################################
    #
    # browse
    #
    ##########################################################################

    def browse(self):

        fformat = get_file_format_from_name(
                      unicode(self.fileformats.currentText()))

        out = unicode(QFileDialog.getOpenFileName(
                  get_config("import_dir"),
                  "All Files (*);;" + fformat.filter,
                  None,
                  None,
                  QString(),
                  fformat.filter))
       
        if out != "":
            self.filename.setText(out)
            
    ##########################################################################
    #
    # apply
    #
    #   Don't rebuild the revision queue here, as the scheduled item have
    #   already been added to it during import.
    #
    ##########################################################################

    def apply(self):

        fname = unicode(self.filename.text()).encode("utf-8")
        fformat_name = unicode(self.fileformats.currentText())
        cat_name = unicode(self.categories.currentText())
        reset_learning_data = self.reset_box.isChecked()
        status = import_file(
                     fname, fformat_name, cat_name, reset_learning_data)

        if status == False:
            QMessageBox.critical(None,
                 self.trUtf8("Mnemosyne"),
                 self.trUtf8("File doesn't appear to be in " +\
                             "the correct format."),
                 self.trUtf8("&OK"), QString(), QString(), 0, -1)
        else:
            set_config("import_dir", os.path.dirname(fname))
        
        self.close()

==> mnemosyne_1.0.orig.tar.gz: mnemosyne-1.0/mnemosyne/pyqt_ui/import_dlg.py <==
##############################################################################
#
# Widget to import items <Peter.Bienstman@UGent.be>
#
##############################################################################

from qt import *

from mnemosyne.core import *
from import_frm import *
from message_boxes import *



##############################################################################
#
# ImportDlg
#
##############################################################################

class ImportDlg(ImportFrm):

    ##########################################################################
    #
    # __init__
    #
    ##########################################################################

    def __init__(self,parent = None,name = None,modal = 0,fl = 0):
        
        ImportFrm.__init__(self,parent,name,modal,fl)

        for fformat in get_importable_file_formats():
            self.fileformats.insertItem(fformat.name)

        self.fileformats.setCurrentText(get_config("import_format"))

        self.categories.insertItem(self.trUtf8("<default>"))
        for cat in get_categories():
            if cat.name != self.trUtf8("<default>"):
                self.categories.insertItem(cat.name)

        self.reset_box.setChecked(get_config("reset_learning_data_import"))
        
        self.connect(self.browse_button, SIGNAL("clicked()"), self.browse)
        self.connect(self.ok_button,     SIGNAL("clicked()"), self.apply)

    ##########################################################################
    #
    # browse
    #
    ##########################################################################

    def browse(self):

        fformat = get_file_format_from_name(
                      unicode(self.fileformats.currentText()))

        out = unicode(QFileDialog.getOpenFileName(
              expand_path(get_config("import_dir")),
              self.trUtf8("All Files (*);;").append(QString(fformat.filter)),
              self, None, self.trUtf8("Import"), fformat.filter))
       
        if out != "":
            self.filename.setText(out)
            
    ##########################################################################
    #
    # apply
    #
    #   Don't rebuild the revision queue here, as the scheduled item have
    #   already been added to it during import.
    #
    ##########################################################################

    def apply(self):

        fname = unicode(self.filename.text())
        fformat_name = unicode(self.fileformats.currentText())
        cat_name = unicode(self.categories.currentText())
        reset_learning_data = self.reset_box.isChecked()

        try:
            import_file(fname, fformat_name, cat_name, reset_learning_data)
        except MnemosyneError, e:
            messagebox_errors(e) # Needs to be caught at this level.

        set_config("import_dir", contract_path(os.path.dirname(fname)))
        set_config("import_format", fformat_name)
        set_config("reset_learning_data_import", reset_learning_data)
        
        self.close()
